Pixel.py
=========================================================

|PyVersion| |PyPI|

Image Data Preprocessing Toolkit

What can Pixel.py be used for?
--------------------------------
- Creating a unified dataset
- Image data preprocessing

Motivation to create another API for image data processing
----------------------------------------------------------
In the course of writing my bachelor thesis, I encountered many problems when processing image datasets. These were mostly incomplete libraries that did not cover my need. For this reason I decided to develop my own library and put it for public use.


.. |PyPI| image:: https://img.shields.io/pypi/v/pixel.py.svg?style=flat-square
.. |PyVersion| image:: https://img.shields.io/pypi/pyversions/pixel.py.svg?style=flat-square